@@ -191,8 +191,8 @@ pub fn generate<T: Service>(
             }
 
             // export endpoint
-            impl <T :#server_trait> crate::lib::micro::grpc_router::EndpointService for  #server_service<T>  {
-                 fn endpoints(&self) -> Vec<String> {
+            impl <T :#server_trait> #server_service<T> {
+                pub fn endpoints(&self) -> Vec<String> {
                     vec!(#endpoints)
                 }
             }
